oa_gateway_adapter::tls

Function install_provider

fn install_provider()
Installs the ring crypto provider as the process default, if one is not already installed. Idempotent: a second install attempt is expected once both an OWP and a STOMP adapter configure TLS in the same process, and is silently discarded.